<?php
/**
 * A FiFo file-based stack
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2014 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class FiFoFileStack extends BaseFileStack implements StackableFile, Registerable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$fileName		Absolute Name of stack file
	 * @param	$type			Type of this stack (e.g. url_source for URL sources)
	 * @return	$stackInstance	An instance of a Stackable class
	 */
	public final static function createFiFoFileStack ($fileName, $type) {
		// Get new instance
		$stackInstance = new FiFoFileStack();

		// Init this stack
		$stackInstance->initFileStack($fileName, $type);

		// Return the prepared instance
		return $stackInstance;
	}

	/**
	 * Pushs a value on a named stacker
	 *
	 * @param	$stackerName	Name of the stack
	 * @param	$value			Value to push on it
	 * @return	void
	 * @throws	StackerFullException	If the stack is full
	 */
	public function pushNamed ($stackerName, $value) {
		$this->partialStub('stackerName=' . $stackerName . ',value[' . gettype($value) . ']=' . $value);
	}

	/**
	 * 'Pops' a value from a named stacker
	 *
	 * @param	$stackerName	Name of the stack
	 * @return	void
	 * @throws	NoStackerException	If the named stacker was not found
	 * @throws	EmptyStackerException	If the named stacker is empty
	 */
	public function popNamed ($stackerName) {
		$this->partialStub('stackerName=' . $stackerName);
	}

	/**
	 * Get value from named stacker
	 *
	 * @param	$stackerName	Name of the stack
	 * @return	$value			Value of last added value
	 * @throws	NoStackerException	If the named stacker was not found
	 * @throws	EmptyStackerException	If the named stacker is empty
	 */
	public function getNamed ($stackerName) {
		$this->partialStub('stackerName=' . $stackerName);
	}

	/**
	 * Seeks to given position
	 *
	 * @param	$seekPosition	Seek position in file
	 * @return	$status			Status of this operation
	 */
	public function seek ($seekPosition) {
		$this->partialStub('seekPosition=' . $seekPosition);
	}

	/**
	 * Size of file stack
	 *
	 * @return	$size	Size (in bytes) of file
	 */
	public function size () {
		$this->partialStub();
	}
}

// [EOF]
?>
